What is the Benker grid?
========================

![Anton Benker grid][benker-grid]

Named after the master carpenter and avid dowser Anton Benker, the Benker grid is a spatial system comprised of rows and columns of cubes with a length and breadth measurement of 10 meters (32’9.7”) (Dale, 2009, 108). It is also referred to as the 10 Meter System and the Benker Cubical System. Each cube is electrically charged and the polarity changes from one cube to the next. A positively charged cube should support and encourage life processes, but it can have the opposite effect if exposure is excessive. Similarly, negatively charged cubes usually have a calming effect but can also extract energy from the body if exposure becomes excessive. Electromagnetic influences (electrosmog) distort and amplify the intensity and spread of the Benker grid. This can, in turn, create areas of irritation that are extremely threatening to our health.

Anton Benker conducted experiments on multiple sclerosis and cancer patients, which confirmed their connection with the Benker Cubical System. Researchers have also proposed that, like the Curry grid, the Benker grid is the result of cosmic influences and not of radiation from the Earth’s interior.

[benker-grid]: benker-grid.jpeg "This picture is a simplified representation of the Benker grid. The cubes are about 10 meters high and wide and are spaced about 1 meter apart."